[**@rickosborne/foundation v2024.12.27**](../README.md)

***

[@rickosborne/foundation](../README.md) / IfWriteOnlyDescriptor

# Type Alias: IfWriteOnlyDescriptor\<T, D\>

> **IfWriteOnlyDescriptor**\<`T`, `D`\>: `D` *extends* [`SetPropertyDescriptor`](SetPropertyDescriptor.md)\<`unknown`\> ? `T` : `never`

Filter type <kbd>T</kbd> based on whether the property descriptor
<kbd>D</kbd> would produce a write-only property.
Note:
JS has a concept of a write-only property, and the unit tests cover this.
However, TS doesn't have a way of expressing it, at least as of v5.8.
So for now, it goes into the read-write bucket, even though you can't
actually read from it.
The alternative would be to set it to `undefined`, to show you can't
read from it ... but then you lose the type info for the setter.  Yuck.
For now ...
The types below will, ahem, mangle the types they produce.  Just a little.
If you produce a setter-only property, it will end up looking like:
```typescript
const withSetterOnly: WithSetterOnly = addProperty({}, "whatever", { set: (value: string) => void(whatever(value)) });
type WithSetterOnly = {
   whatever: string;
   whateverIsWriteOnly?: undefined;
}
```
So you get a reminder without breaking anything too hard.

## Type Parameters

• **T**

• **D** *extends* [`TypedPropertyDescriptor`](TypedPropertyDescriptor.md)\<`unknown`\>

## Defined in

[foundation/ts/add-property.ts:94](https://github.com/rickosborne/es-js-ts/blob/78a07c48a8ee66acad83b938575d051189c41326/foundation/ts/add-property.ts#L94)
